@@ -49,15 +49,15 @@ from .literals import (
     TargetFilterNameType,
 )
 from .type_defs import (
-    ListApplicationRevisionsOutputResponseTypeDef,
-    ListApplicationsOutputResponseTypeDef,
-    ListDeploymentConfigsOutputResponseTypeDef,
-    ListDeploymentGroupsOutputResponseTypeDef,
-    ListDeploymentInstancesOutputResponseTypeDef,
-    ListDeploymentsOutputResponseTypeDef,
-    ListDeploymentTargetsOutputResponseTypeDef,
-    ListGitHubAccountTokenNamesOutputResponseTypeDef,
-    ListOnPremisesInstancesOutputResponseTypeDef,
+    ListApplicationRevisionsOutputTypeDef,
+    ListApplicationsOutputTypeDef,
+    ListDeploymentConfigsOutputTypeDef,
+    ListDeploymentGroupsOutputTypeDef,
+    ListDeploymentInstancesOutputTypeDef,
+    ListDeploymentsOutputTypeDef,
+    ListDeploymentTargetsOutputTypeDef,
+    ListGitHubAccountTokenNamesOutputTypeDef,
+    ListOnPremisesInstancesOutputTypeDef,
     PaginatorConfigTypeDef,
     TagFilterTypeDef,
     TimeRangeTypeDef,
@@ -78,7 +78,7 @@ __all__ = (
 
 class ListApplicationRevisionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplicationRevisions)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplicationRevisions)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listapplicationrevisionspaginator)
     """
 
@@ -92,61 +92,61 @@ class ListApplicationRevisionsPaginator(Boto3Paginator):
         s3KeyPrefix: str = None,
         deployed: ListStateFilterActionType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListApplicationRevisionsOutputResponseTypeDef]:
+    ) -> Iterator[ListApplicationRevisionsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplicationRevisions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplicationRevisions.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listapplicationrevisionspaginator)
         """
 
 
 class ListApplicationsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplications)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplications)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listapplicationspaginator)
     """
 
     def paginate(
         self, *, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListApplicationsOutputResponseTypeDef]:
+    ) -> Iterator[ListApplicationsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplications.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplications.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listapplicationspaginator)
         """
 
 
 class ListDeploymentConfigsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentConfigs)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentConfigs)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listdeploymentconfigspaginator)
     """
 
     def paginate(
         self, *, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListDeploymentConfigsOutputResponseTypeDef]:
+    ) -> Iterator[ListDeploymentConfigsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentConfigs.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentConfigs.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listdeploymentconfigspaginator)
         """
 
 
 class ListDeploymentGroupsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentGroups)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentGroups)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listdeploymentgroupspaginator)
     """
 
     def paginate(
         self, *, applicationName: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListDeploymentGroupsOutputResponseTypeDef]:
+    ) -> Iterator[ListDeploymentGroupsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentGroups.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentGroups.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listdeploymentgroupspaginator)
         """
 
 
 class ListDeploymentInstancesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentInstances)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentInstances)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listdeploymentinstancespaginator)
     """
 
@@ -157,16 +157,16 @@ class ListDeploymentInstancesPaginator(Boto3Paginator):
         instanceStatusFilter: List[InstanceStatusType] = None,
         instanceTypeFilter: List[InstanceTypeType] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListDeploymentInstancesOutputResponseTypeDef]:
+    ) -> Iterator[ListDeploymentInstancesOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentInstances.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentInstances.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listdeploymentinstancespaginator)
         """
 
 
 class ListDeploymentTargetsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentTargets)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentTargets)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listdeploymenttargetspaginator)
     """
 
@@ -176,16 +176,16 @@ class ListDeploymentTargetsPaginator(Boto3Paginator):
         deploymentId: str = None,
         targetFilters: Dict[TargetFilterNameType, List[str]] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListDeploymentTargetsOutputResponseTypeDef]:
+    ) -> Iterator[ListDeploymentTargetsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentTargets.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentTargets.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listdeploymenttargetspaginator)
         """
 
 
 class ListDeploymentsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeployments)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeployments)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listdeploymentspaginator)
     """
 
@@ -198,31 +198,31 @@ class ListDeploymentsPaginator(Boto3Paginator):
         includeOnlyStatuses: List[DeploymentStatusType] = None,
         createTimeRange: "TimeRangeTypeDef" = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListDeploymentsOutputResponseTypeDef]:
+    ) -> Iterator[ListDeploymentsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeployments.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeployments.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listdeploymentspaginator)
         """
 
 
 class ListGitHubAccountTokenNamesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListGitHubAccountTokenNames)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codedeploy.html#CodeDeploy.Paginator.ListGitHubAccountTokenNames)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listgithubaccounttokennamespaginator)
     """
 
     def paginate(
         self, *, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListGitHubAccountTokenNamesOutputResponseTypeDef]:
+    ) -> Iterator[ListGitHubAccountTokenNamesOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListGitHubAccountTokenNames.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codedeploy.html#CodeDeploy.Paginator.ListGitHubAccountTokenNames.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listgithubaccounttokennamespaginator)
         """
 
 
 class ListOnPremisesInstancesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListOnPremisesInstances)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codedeploy.html#CodeDeploy.Paginator.ListOnPremisesInstances)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listonpremisesinstancespaginator)
     """
 
@@ -232,8 +232,8 @@ class ListOnPremisesInstancesPaginator(Boto3Paginator):
         registrationStatus: RegistrationStatusType = None,
         tagFilters: List["TagFilterTypeDef"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListOnPremisesInstancesOutputResponseTypeDef]:
+    ) -> Iterator[ListOnPremisesInstancesOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListOnPremisesInstances.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/codedeploy.html#CodeDeploy.Paginator.ListOnPremisesInstances.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listonpremisesinstancespaginator)
         """
